==> haskell-mwc-random-0.13.6.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mwc-random
version: 0.13.6.0
id: mwc-random-0.13.6.0-FkwmwAh2ZNWGdUe7qkQMIm
key: mwc-random-0.13.6.0-FkwmwAh2ZNWGdUe7qkQMIm
license: BSD3
copyright: 2009, 2010, 2011 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/mwc-random
synopsis: Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    System.Random.MWC System.Random.MWC.Distributions
    System.Random.MWC.CondensedTable
abi: e8d2258138190df4977db5b1bb9ea960
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/mwc-random-0.13.6.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/mwc-random-0.13.6.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/mwc-random-0.13.6.0
hs-libraries: HSmwc-random-0.13.6.0-FkwmwAh2ZNWGdUe7qkQMIm
depends:
    base-4.9.0.0 math-functions-0.2.1.0-31FvveTLTlqClGw5YZ5Avx
    primitive-0.6.2.0-3HSsNCfUEEE4fjqDYVydYZ time-1.6.0.1
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html: /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mwc-random-0.13.6.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mwc-random
version: 0.13.6.0
id: mwc-random-0.13.6.0-K5ePRTjCwYQ3u7Qp4sh2LR
key: mwc-random-0.13.6.0-K5ePRTjCwYQ3u7Qp4sh2LR
license: BSD3
copyright: 2009, 2010, 2011 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/mwc-random
synopsis: Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    System.Random.MWC System.Random.MWC.Distributions
    System.Random.MWC.CondensedTable
abi: 110979416c7d5bdf4256cb0d5d207ea5
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/mwc-random-0.13.6.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/mwc-random-0.13.6.0
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/mwc-random-0.13.6.0
hs-libraries: HSmwc-random-0.13.6.0-K5ePRTjCwYQ3u7Qp4sh2LR
depends:
    base-4.9.1.0 math-functions-0.2.1.0-F0c8wUJFuGnIPpddl5zobd
    primitive-0.6.2.0-4578caNkWQ54Gt1mxLF2Yh time-1.6.0.1
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html: /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
